@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,6 +13,7 @@
  *     Pierre-Yves B. <pyvesdev@gmail.com> - Generation of equals and hashcode with java 7 Objects.equals and Objects.hashcode - https://bugs.eclipse.org/424214
  *     Pierre-Yves B. <pyvesdev@gmail.com> - Different behaviour when generating hashCode and equals - https://bugs.eclipse.org/539589
  *     Pierre-Yves B. <pyvesdev@gmail.com> - Confusing name when generating hashCode and equals with outer type - https://bugs.eclipse.org/539872
+ *     Pierre-Yves B. <pyvesdev@gmail.com> - Allow hashCode and equals generation when no fields but a super/enclosing class that implements them - https://bugs.eclipse.org/539901
  *******************************************************************************/
 package org.eclipse.jdt.ui.tests.core.source;
 
@@ -146,9 +147,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"	float aFloat;\r\n" +
 				"	long aLong;\r\n" +
 				"	java.lang.annotation.ElementType anEnum;\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#hashCode()\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public int hashCode() {\r\n" +
 				"		final int prime = 31;\r\n" +
@@ -165,9 +163,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"		result = prime * result + ((anEnum == null) ? 0 : anEnum.hashCode());\r\n" +
 				"		return result;\r\n" +
 				"	}\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#equals(java.lang.Object)\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public boolean equals(Object obj) {\r\n" +
 				"		if (this == obj)\r\n" +
@@ -234,9 +229,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"	\r\n" +
 				"	boolean aBool;\r\n" +
 				"\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#hashCode()\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public int hashCode() {\r\n" +
 				"		final int prime = 31;\r\n" +
@@ -245,9 +237,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"		return result;\r\n" +
 				"	}\r\n" +
 				"\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#equals(java.lang.Object)\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public boolean equals(Object obj) {\r\n" +
 				"		if (this == obj)\r\n" +
@@ -301,9 +290,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"	\r\n" +
 				"	A anA;\r\n" +
 				"	B aB;\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#hashCode()\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public int hashCode() {\r\n" +
 				"		final int prime = 31;\r\n" +
@@ -312,9 +298,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"		result = prime * result + ((aB == null) ? 0 : aB.hashCode());\r\n" +
 				"		return result;\r\n" +
 				"	}\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#equals(java.lang.Object)\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public boolean equals(Object obj) {\r\n" +
 				"		if (this == obj)\r\n" +
@@ -376,9 +359,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"	\r\n" +
 				"	A anA;\r\n" +
 				"	B aB;\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#hashCode()\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public int hashCode() {\r\n" +
 				"		final int prime = 31;\r\n" +
@@ -387,9 +367,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"		result = prime * result + ((aB == null) ? 0 : aB.hashCode());\r\n" +
 				"		return result;\r\n" +
 				"	}\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#equals(java.lang.Object)\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public boolean equals(Object obj) {\r\n" +
 				"		if (this == obj)\r\n" +
@@ -446,9 +423,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"	\r\n" +
 				"	A[] someAs;\r\n" +
 				"	int[] someInts;\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#hashCode()\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public int hashCode() {\r\n" +
 				"		final int prime = 31;\r\n" +
@@ -457,9 +431,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"		result = prime * result + Arrays.hashCode(someInts);\r\n" +
 				"		return result;\r\n" +
 				"	}\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#equals(java.lang.Object)\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public boolean equals(Object obj) {\r\n" +
 				"		if (this == obj)\r\n" +
@@ -511,9 +482,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"	int someInt;\r\n" +
 				"	\r\n" +
 				"	public void foo() {}\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#hashCode()\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public int hashCode() {\r\n" +
 				"		final int prime = 31;\r\n" +
@@ -521,9 +489,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"		result = prime * result + someInt;\r\n" +
 				"		return result;\r\n" +
 				"	}\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#equals(java.lang.Object)\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public boolean equals(Object obj) {\r\n" +
 				"		if (this == obj)\r\n" +
@@ -578,9 +543,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"	List<Integer> intList;\r\n" +
 				"	HashMap<Integer, List<Boolean>> intBoolHashMap;\r\n" +
 				"	E someEnum;\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#hashCode()\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public int hashCode() {\r\n" +
 				"		final int prime = 31;\r\n" +
@@ -590,9 +552,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"		result = prime * result + ((someEnum == null) ? 0 : someEnum.hashCode());\r\n" +
 				"		return result;\r\n" +
 				"	}\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#equals(java.lang.Object)\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public boolean equals(Object obj) {\r\n" +
 				"		if (this == obj)\r\n" +
@@ -646,9 +605,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"public class A {\r\n" +
 				"	double d1;\r\n" +
 				"	double d2;\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#hashCode()\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public int hashCode() {\r\n" +
 				"		final int prime = 31;\r\n" +
@@ -660,9 +616,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"		result = prime * result + (int) (temp ^ (temp >>> 32));\r\n" +
 				"		return result;\r\n" +
 				"	}\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#equals(java.lang.Object)\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public boolean equals(Object obj) {\r\n" +
 				"		if (this == obj)\r\n" +
@@ -710,9 +663,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"	boolean result;\r\n" +
 				"	String obj;\r\n" +
 				"	double someOther;\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#hashCode()\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public int hashCode() {\r\n" +
 				"		final int prime = 31;\r\n" +
@@ -726,9 +676,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"		result = prime * result + (int) (temp ^ (temp >>> 32));\r\n" +
 				"		return result;\r\n" +
 				"	}\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#equals(java.lang.Object)\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public boolean equals(Object obj) {\r\n" +
 				"		if (this == obj)\r\n" +
@@ -791,9 +738,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"	double aDouble;\r\n" +
 				"	float aFloat;\r\n" +
 				"	long aLong;\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#hashCode()\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public int hashCode() {\r\n" +
 				"		final int prime = 31;\r\n" +
@@ -809,9 +753,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"		result = prime * result + (int) (aLong ^ (aLong >>> 32));\r\n" +
 				"		return result;\r\n" +
 				"	}\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#equals(java.lang.Object)\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public boolean equals(Object obj) {\r\n" +
 				"		if (this == obj)\r\n" +
@@ -876,9 +817,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"	\r\n" +
 				"	boolean aBool;\r\n" +
 				"\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#hashCode()\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public int hashCode() {\r\n" +
 				"		final int prime = 31;\r\n" +
@@ -887,9 +825,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"		return result;\r\n" +
 				"	}\r\n" +
 				"\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#equals(java.lang.Object)\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public boolean equals(Object obj) {\r\n" +
 				"		if (this == obj)\r\n" +
@@ -943,9 +878,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"	\r\n" +
 				"	A anA;\r\n" +
 				"	B aB;\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#hashCode()\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public int hashCode() {\r\n" +
 				"		final int prime = 31;\r\n" +
@@ -954,9 +886,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"		result = prime * result + ((aB == null) ? 0 : aB.hashCode());\r\n" +
 				"		return result;\r\n" +
 				"	}\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#equals(java.lang.Object)\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public boolean equals(Object obj) {\r\n" +
 				"		if (this == obj)\r\n" +
@@ -1019,9 +948,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"	\r\n" +
 				"	A anA;\r\n" +
 				"	B aB;\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#hashCode()\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public int hashCode() {\r\n" +
 				"		final int prime = 31;\r\n" +
@@ -1030,9 +956,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"		result = prime * result + ((aB == null) ? 0 : aB.hashCode());\r\n" +
 				"		return result;\r\n" +
 				"	}\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#equals(java.lang.Object)\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public boolean equals(Object obj) {\r\n" +
 				"		if (this == obj)\r\n" +
@@ -1108,16 +1031,10 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"	String aString;\r\n" +
 				"	List<String> aListOfStrings;\r\n" +
 				"	ElementType anEnum;\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#hashCode()\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public int hashCode() {\r\n" +
 				"		return Objects.hash(aBool, aByte, aChar, anInt, aDouble, aFloat, aLong, aString, aListOfStrings, anEnum);\r\n" +
 				"	}\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#equals(java.lang.Object)\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public boolean equals(Object obj) {\r\n" +
 				"		if (this == obj)\r\n" +
@@ -1162,17 +1079,11 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"public class A {\r\n" +
 				"	String aString;\r\n" +
 				"\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#hashCode()\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public int hashCode() {\r\n" +
 				"		return Objects.hash(aString);\r\n" +
 				"	}\r\n" +
 				"\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#equals(java.lang.Object)\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public boolean equals(Object obj) {\r\n" +
 				"		if (this == obj)\r\n" +
@@ -1231,16 +1142,10 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"	long aLong;\r\n" +
 				"	String aString;\r\n" +
 				"	List<String> aListOfStrings;\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#hashCode()\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public int hashCode() {\r\n" +
 				"		return Objects.hash(aBool, aByte, aChar, anInt, aDouble, aFloat, aLong, aString, aListOfStrings);\r\n" +
 				"	}\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#equals(java.lang.Object)\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public boolean equals(Object obj) {\r\n" +
 				"		if (this == obj)\r\n" +
@@ -1303,9 +1208,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"	String aString;\r\n" +
 				"	List<String> aListOfStrings;\r\n" +
 				"	int[] anArrayOfInts;\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#hashCode()\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public int hashCode() {\r\n" +
 				"		final int prime = 31;\r\n" +
@@ -1314,9 +1216,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"		result = prime * result + Objects.hash(aBool, aByte, aChar, anInt, aDouble, aFloat, aLong, aString, aListOfStrings);\r\n" +
 				"		return result;\r\n" +
 				"	}\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#equals(java.lang.Object)\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public boolean equals(Object obj) {\r\n" +
 				"		if (this == obj)\r\n" +
@@ -1378,9 +1277,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"	String aString;\r\n" +
 				"	List<String> aListOfStrings;\r\n" +
 				"	Cloneable[] anArrayOfCloneables;\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#hashCode()\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public int hashCode() {\r\n" +
 				"		final int prime = 31;\r\n" +
@@ -1389,9 +1285,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"		result = prime * result + Objects.hash(aBool, aByte, aChar, anInt, aDouble, aFloat, aLong, aString, aListOfStrings);\r\n" +
 				"		return result;\r\n" +
 				"	}\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#equals(java.lang.Object)\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public boolean equals(Object obj) {\r\n" +
 				"		if (this == obj)\r\n" +
@@ -1455,9 +1348,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"	String aString;\r\n" +
 				"	List<String> aListOfStrings;\r\n" +
 				"	Serializable[] anArrayOfSerializables;\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#hashCode()\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public int hashCode() {\r\n" +
 				"		final int prime = 31;\r\n" +
@@ -1466,9 +1356,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"		result = prime * result + Objects.hash(aBool, aByte, aChar, anInt, aDouble, aFloat, aLong, aString, aListOfStrings);\r\n" +
 				"		return result;\r\n" +
 				"	}\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#equals(java.lang.Object)\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public boolean equals(Object obj) {\r\n" +
 				"		if (this == obj)\r\n" +
@@ -1530,9 +1417,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"	String aString;\r\n" +
 				"	List<String> aListOfStrings;\r\n" +
 				"	Object[] anArrayOfObjects;\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#hashCode()\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public int hashCode() {\r\n" +
 				"		final int prime = 31;\r\n" +
@@ -1541,9 +1425,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"		result = prime * result + Objects.hash(aBool, aByte, aChar, anInt, aDouble, aFloat, aLong, aString, aListOfStrings);\r\n" +
 				"		return result;\r\n" +
 				"	}\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#equals(java.lang.Object)\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public boolean equals(Object obj) {\r\n" +
 				"		if (this == obj)\r\n" +
@@ -1588,9 +1469,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"public class A <S extends Serializable, N extends Number> {\r\n" +
 				"	S[] anArrayOfS;\r\n" +
 				"	N[] anArrayOfN;\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#hashCode()\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public int hashCode() {\r\n" +
 				"		final int prime = 31;\r\n" +
@@ -1599,9 +1477,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"		result = prime * result + Arrays.hashCode(anArrayOfN);\r\n" +
 				"		return result;\r\n" +
 				"	}\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#equals(java.lang.Object)\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public boolean equals(Object obj) {\r\n" +
 				"		if (this == obj)\r\n" +
@@ -1663,9 +1538,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"	String aString;\r\n" +
 				"	List<String> aListOfStrings;\r\n" +
 				"	int[][] anArrayOfInts;\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#hashCode()\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public int hashCode() {\r\n" +
 				"		final int prime = 31;\r\n" +
@@ -1674,9 +1546,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"		result = prime * result + Objects.hash(aBool, aByte, aChar, anInt, aDouble, aFloat, aLong, aString, aListOfStrings);\r\n" +
 				"		return result;\r\n" +
 				"	}\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#equals(java.lang.Object)\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public boolean equals(Object obj) {\r\n" +
 				"		if (this == obj)\r\n" +
@@ -1741,9 +1610,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"	List<String> aListOfStrings;\r\n" +
 				"	int[] anArrayOfInts;\r\n" +
 				"	String[][] anArrayOfStrings;\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#hashCode()\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public int hashCode() {\r\n" +
 				"		final int prime = 31;\r\n" +
@@ -1753,9 +1619,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"		result = prime * result + Objects.hash(aBool, aByte, aChar, anInt, aDouble, aFloat, aLong, aString, aListOfStrings);\r\n" +
 				"		return result;\r\n" +
 				"	}\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#equals(java.lang.Object)\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public boolean equals(Object obj) {\r\n" +
 				"		if (this == obj)\r\n" +
@@ -1801,9 +1664,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"public class A {\r\n" +
 				"	int[] anArrayOfInts;\r\n" +
 				"	String[][] anArrayOfStrings;\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#hashCode()\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public int hashCode() {\r\n" +
 				"		final int prime = 31;\r\n" +
@@ -1812,9 +1672,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"		result = prime * result + Arrays.deepHashCode(anArrayOfStrings);\r\n" +
 				"		return result;\r\n" +
 				"	}\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#equals(java.lang.Object)\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public boolean equals(Object obj) {\r\n" +
 				"		if (this == obj)\r\n" +
@@ -1859,9 +1716,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"	public class Inner {\r\n" +
 				"		int x;\r\n" +
 				"\r\n" +
-				"		/* (non-Javadoc)\r\n" +
-				"		 * @see java.lang.Object#hashCode()\r\n" +
-				"		 */\r\n" +
 				"		@Override\r\n" +
 				"		public int hashCode() {\r\n" +
 				"			final int prime = 31;\r\n" +
@@ -1871,9 +1725,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"			return result;\r\n" +
 				"		}\r\n" +
 				"\r\n" +
-				"		/* (non-Javadoc)\r\n" +
-				"		 * @see java.lang.Object#equals(java.lang.Object)\r\n" +
-				"		 */\r\n" +
 				"		@Override\r\n" +
 				"		public boolean equals(Object obj) {\r\n" +
 				"			if (this == obj)\r\n" +
@@ -1928,9 +1779,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"	public class Inner {\r\n" +
 				"		int x;\r\n" +
 				"\r\n" +
-				"		/* (non-Javadoc)\r\n" +
-				"		 * @see java.lang.Object#hashCode()\r\n" +
-				"		 */\r\n" +
 				"		@Override\r\n" +
 				"		public int hashCode() {\r\n" +
 				"			final int prime = 31;\r\n" +
@@ -1940,9 +1788,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"			return result;\r\n" +
 				"		}\r\n" +
 				"\r\n" +
-				"		/* (non-Javadoc)\r\n" +
-				"		 * @see java.lang.Object#equals(java.lang.Object)\r\n" +
-				"		 */\r\n" +
 				"		@Override\r\n" +
 				"		public boolean equals(Object obj) {\r\n" +
 				"			if (this == obj)\r\n" +
@@ -1992,9 +1837,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"	\r\n" +
 				"	boolean aBool;\r\n" +
 				"	Object obj;\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#hashCode()\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public int hashCode() {\r\n" +
 				"		final int prime = 31;\r\n" +
@@ -2003,9 +1845,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"		result = prime * result + ((obj == null) ? 0 : obj.hashCode());\r\n" +
 				"		return result;\r\n" +
 				"	}\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#equals(java.lang.Object)\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public boolean equals(Object obj) {\r\n" +
 				"		if (this == obj) {\r\n" +
@@ -2114,9 +1953,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 					"	}\r\n" +
 					"	A[] anArray;\r\n" +
 					"	double[] anDArray;\r\n" +
-					"	/* (non-Javadoc)\r\n" +
-					"	 * @see java.lang.Object#hashCode()\r\n" +
-					"	 */\r\n" +
 					"	public int hashCode() {\r\n" +
 					"		final int prime = 31;\r\n" +
 					"		int result = super.hashCode();\r\n" +
@@ -2124,9 +1960,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 					"		result = prime * result + A.hashCode(anDArray);\r\n" +
 					"		return result;\r\n" +
 					"	}\r\n" +
-					"	/* (non-Javadoc)\r\n" +
-					"	 * @see java.lang.Object#equals(java.lang.Object)\r\n" +
-					"	 */\r\n" +
 					"	public boolean equals(Object obj) {\r\n" +
 					"		if (this == obj)\r\n" +
 					"			return true;\r\n" +
@@ -2190,9 +2023,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"\r\n" +
 				"	String aString;\r\n" +
 				"\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#hashCode()\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public int hashCode() {\r\n" +
 				"		final int prime = 31;\r\n" +
@@ -2201,9 +2031,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 				"		return result;\r\n" +
 				"	}\r\n" +
 				"\r\n" +
-				"	/* (non-Javadoc)\r\n" +
-				"	 * @see java.lang.Object#equals(java.lang.Object)\r\n" +
-				"	 */\r\n" +
 				"	@Override\r\n" +
 				"	public boolean equals(Object obj) {\r\n" +
 				"		if (this == obj)\r\n" +
@@ -2222,6 +2049,58 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 		compareSource(expected, a.getSource());
 	}
 
+	/**
+	 * Test implementation based only on super class
+	 * 
+	 * @throws Exception
+	 */
+	public void testSubTypeNoFields() throws Exception {
+		fPackageP.createCompilationUnit("B.java", "package p;\r\n" +
+				"\r\n" +
+				"public class B {\r\n" +
+				"	public int hashCode() {\r\n" +
+				"		return 1;\r\n" +
+				"	}\r\n" +
+				"	public boolean equals(Object obj) {\r\n" +
+				"		return obj instanceof B;\r\n" +
+				"	}\r\n" +
+				"\r\n" +
+				"}\r\n" +
+				"", true, null);
+
+		ICompilationUnit a= fPackageP.createCompilationUnit("A.java", "package p;\r\n" +
+				"\r\n" +
+				"public class A extends B {\r\n" +
+				"}\r\n" +
+				"", true, null);
+
+		runOperation(a.getType("A"), new IField[0], false, false);
+
+		String expected= "package p;\r\n" +
+				"\r\n" +
+				"public class A extends B {\r\n" +
+				"\r\n" +
+				"	@Override\r\n" +
+				"	public int hashCode() {\r\n" +
+				"		return super.hashCode();\r\n" +
+				"	}\r\n" +
+				"\r\n" +
+				"	@Override\r\n" +
+				"	public boolean equals(Object obj) {\r\n" +
+				"		if (this == obj)\r\n" +
+				"			return true;\r\n" +
+				"		if (!super.equals(obj))\r\n" +
+				"			return false;\r\n" +
+				"		if (getClass() != obj.getClass())\r\n" +
+				"			return false;\r\n" +
+				"		return true;\r\n" +
+				"	}\r\n" +
+				"}\r\n" +
+				"";
+
+		compareSource(expected, a.getSource());
+	}
+
 	public void testInsertAt() throws Exception {
 		StringBuffer buf= new StringBuffer();
 		buf.append("package p;\n");
@@ -2373,9 +2252,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 					"\r\n" +
 					"	 int[][][] a = new int[][][] {{null}};\r\n" +
 					"	 int[][][] b = new int[][][] {{null}};\r\n" +
-					"	/* (non-Javadoc)\r\n" +
-					"	 * @see java.lang.Object#hashCode()\r\n" +
-					"	 */\r\n" +
 					"	@Override\r\n" +
 					"	public int hashCode() {\r\n" +
 					"		final int prime = 31;\r\n" +
@@ -2384,9 +2260,6 @@ public class GenerateHashCodeEqualsTest extends SourceTestCase {
 					"		result = prime * result + Arrays.deepHashCode(b);\r\n" +
 					"		return result;\r\n" +
 					"	}\r\n" +
-					"	/* (non-Javadoc)\r\n" +
-					"	 * @see java.lang.Object#equals(java.lang.Object)\r\n" +
-					"	 */\r\n" +
 					"	@Override\r\n" +
 					"	public boolean equals(Object obj) {\r\n" +
 					"		if (this == obj)\r\n" +
